"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2323 import (
        AdjustedSpeed,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2324 import (
        AdjustmentFactors,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2325 import (
        BearingLoads,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2326 import (
        BearingRatingLife,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2327 import (
        DynamicAxialLoadCarryingCapacity,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2328 import (
        Frequencies,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2329 import (
        FrequencyOfOverRolling,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2330 import (
        Friction,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2331 import (
        FrictionalMoment,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2332 import (
        FrictionSources,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2333 import (
        Grease,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2334 import (
        GreaseLifeAndRelubricationInterval,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2335 import (
        GreaseQuantity,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2336 import (
        InitialFill,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2337 import (
        LifeModel,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2338 import (
        MinimumLoad,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2339 import (
        OperatingViscosity,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2340 import (
        PermissibleAxialLoad,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2341 import (
        RotationalFrequency,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2342 import (
        SKFAuthentication,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2343 import (
        SKFCalculationResult,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2344 import (
        SKFCredentials,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2345 import (
        SKFModuleResults,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2346 import (
        StaticSafetyFactors,
    )
    from mastapy._private.bearings.bearing_results.rolling.skf_module._2347 import (
        Viscosities,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.bearings.bearing_results.rolling.skf_module._2323": ["AdjustedSpeed"],
        "_private.bearings.bearing_results.rolling.skf_module._2324": [
            "AdjustmentFactors"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2325": ["BearingLoads"],
        "_private.bearings.bearing_results.rolling.skf_module._2326": [
            "BearingRatingLife"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2327": [
            "DynamicAxialLoadCarryingCapacity"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2328": ["Frequencies"],
        "_private.bearings.bearing_results.rolling.skf_module._2329": [
            "FrequencyOfOverRolling"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2330": ["Friction"],
        "_private.bearings.bearing_results.rolling.skf_module._2331": [
            "FrictionalMoment"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2332": [
            "FrictionSources"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2333": ["Grease"],
        "_private.bearings.bearing_results.rolling.skf_module._2334": [
            "GreaseLifeAndRelubricationInterval"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2335": [
            "GreaseQuantity"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2336": ["InitialFill"],
        "_private.bearings.bearing_results.rolling.skf_module._2337": ["LifeModel"],
        "_private.bearings.bearing_results.rolling.skf_module._2338": ["MinimumLoad"],
        "_private.bearings.bearing_results.rolling.skf_module._2339": [
            "OperatingViscosity"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2340": [
            "PermissibleAxialLoad"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2341": [
            "RotationalFrequency"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2342": [
            "SKFAuthentication"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2343": [
            "SKFCalculationResult"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2344": [
            "SKFCredentials"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2345": [
            "SKFModuleResults"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2346": [
            "StaticSafetyFactors"
        ],
        "_private.bearings.bearing_results.rolling.skf_module._2347": ["Viscosities"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AdjustedSpeed",
    "AdjustmentFactors",
    "BearingLoads",
    "BearingRatingLife",
    "DynamicAxialLoadCarryingCapacity",
    "Frequencies",
    "FrequencyOfOverRolling",
    "Friction",
    "FrictionalMoment",
    "FrictionSources",
    "Grease",
    "GreaseLifeAndRelubricationInterval",
    "GreaseQuantity",
    "InitialFill",
    "LifeModel",
    "MinimumLoad",
    "OperatingViscosity",
    "PermissibleAxialLoad",
    "RotationalFrequency",
    "SKFAuthentication",
    "SKFCalculationResult",
    "SKFCredentials",
    "SKFModuleResults",
    "StaticSafetyFactors",
    "Viscosities",
)



"""FEEntityGroup"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import utility

_FE_ENTITY_GROUP = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses", "FEEntityGroup"
)

if TYPE_CHECKING:
    from typing import Any, Type

    from mastapy._private.nodal_analysis.component_mode_synthesis import (
        _323,
        _324,
        _326,
    )
    from mastapy._private.nodal_analysis.dev_tools_analyses import (
        _277,
        _278,
        _279,
        _281,
        _299,
    )

    Self = TypeVar("Self", bound="FEEntityGroup")
    CastSelf = TypeVar("CastSelf", bound="FEEntityGroup._Cast_FEEntityGroup")

T = TypeVar("T")

__docformat__ = "restructuredtext en"
__all__ = ("FEEntityGroup",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FEEntityGroup:
    """Special nested class for casting FEEntityGroup to subclasses."""

    __parent__: "FEEntityGroup"

    @property
    def element_edge_group(self: "CastSelf") -> "_277.ElementEdgeGroup":
        from mastapy._private.nodal_analysis.dev_tools_analyses import _277

        return self.__parent__._cast(_277.ElementEdgeGroup)

    @property
    def element_face_group(self: "CastSelf") -> "_278.ElementFaceGroup":
        from mastapy._private.nodal_analysis.dev_tools_analyses import _278

        return self.__parent__._cast(_278.ElementFaceGroup)

    @property
    def element_group(self: "CastSelf") -> "_279.ElementGroup":
        from mastapy._private.nodal_analysis.dev_tools_analyses import _279

        return self.__parent__._cast(_279.ElementGroup)

    @property
    def fe_entity_group_integer(self: "CastSelf") -> "_281.FEEntityGroupInteger":
        from mastapy._private.nodal_analysis.dev_tools_analyses import _281

        return self.__parent__._cast(_281.FEEntityGroupInteger)

    @property
    def node_group(self: "CastSelf") -> "_299.NodeGroup":
        from mastapy._private.nodal_analysis.dev_tools_analyses import _299

        return self.__parent__._cast(_299.NodeGroup)

    @property
    def cms_element_face_group(self: "CastSelf") -> "_323.CMSElementFaceGroup":
        from mastapy._private.nodal_analysis.component_mode_synthesis import _323

        return self.__parent__._cast(_323.CMSElementFaceGroup)

    @property
    def cms_element_face_group_of_all_free_faces(
        self: "CastSelf",
    ) -> "_324.CMSElementFaceGroupOfAllFreeFaces":
        from mastapy._private.nodal_analysis.component_mode_synthesis import _324

        return self.__parent__._cast(_324.CMSElementFaceGroupOfAllFreeFaces)

    @property
    def cms_node_group(self: "CastSelf") -> "_326.CMSNodeGroup":
        from mastapy._private.nodal_analysis.component_mode_synthesis import _326

        return self.__parent__._cast(_326.CMSNodeGroup)

    @property
    def fe_entity_group(self: "CastSelf") -> "FEEntityGroup":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class FEEntityGroup(_0.APIBase, Generic[T]):
    """FEEntityGroup

    This is a mastapy class.

    Generic Types:
        T
    """

    TYPE: ClassVar["Type"] = _FE_ENTITY_GROUP

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @name.setter
    @exception_bridge
    @enforce_parameter_types
    def name(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "Name", str(value) if value is not None else ""
        )

    @property
    @exception_bridge
    def number_of_items(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfItems")

        if temp is None:
            return 0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_FEEntityGroup":
        """Cast to another type.

        Returns:
            _Cast_FEEntityGroup
        """
        return _Cast_FEEntityGroup(self)



"""SpiralBevelMeshSingleFlankRating"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private._internal.implicit import overridable
from mastapy._private.gears.rating.conical import _659

_SPIRAL_BEVEL_MESH_SINGLE_FLANK_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Bevel.Standards", "SpiralBevelMeshSingleFlankRating"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating import _479
    from mastapy._private.gears.rating.bevel.standards import _671, _673

    Self = TypeVar("Self", bound="SpiralBevelMeshSingleFlankRating")
    CastSelf = TypeVar(
        "CastSelf",
        bound="SpiralBevelMeshSingleFlankRating._Cast_SpiralBevelMeshSingleFlankRating",
    )


__docformat__ = "restructuredtext en"
__all__ = ("SpiralBevelMeshSingleFlankRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SpiralBevelMeshSingleFlankRating:
    """Special nested class for casting SpiralBevelMeshSingleFlankRating to subclasses."""

    __parent__: "SpiralBevelMeshSingleFlankRating"

    @property
    def conical_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_659.ConicalMeshSingleFlankRating":
        return self.__parent__._cast(_659.ConicalMeshSingleFlankRating)

    @property
    def mesh_single_flank_rating(self: "CastSelf") -> "_479.MeshSingleFlankRating":
        from mastapy._private.gears.rating import _479

        return self.__parent__._cast(_479.MeshSingleFlankRating)

    @property
    def agma_spiral_bevel_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_671.AGMASpiralBevelMeshSingleFlankRating":
        from mastapy._private.gears.rating.bevel.standards import _671

        return self.__parent__._cast(_671.AGMASpiralBevelMeshSingleFlankRating)

    @property
    def gleason_spiral_bevel_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_673.GleasonSpiralBevelMeshSingleFlankRating":
        from mastapy._private.gears.rating.bevel.standards import _673

        return self.__parent__._cast(_673.GleasonSpiralBevelMeshSingleFlankRating)

    @property
    def spiral_bevel_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "SpiralBevelMeshSingleFlankRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SpiralBevelMeshSingleFlankRating(_659.ConicalMeshSingleFlankRating):
    """SpiralBevelMeshSingleFlankRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SPIRAL_BEVEL_MESH_SINGLE_FLANK_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def dynamic_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DynamicFactorBending")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def dynamic_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DynamicFactorContact")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def elastic_coefficient(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ElasticCoefficient")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def geometry_factor_i(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GeometryFactorI")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def inertia_factor_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InertiaFactorContact")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def length_of_line_of_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LengthOfLineOfContact")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def load_distribution_factor_bending(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LoadDistributionFactorBending")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def load_distribution_factor_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LoadDistributionFactorContact")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def load_sharing_ratio_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LoadSharingRatioContact")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def overload_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OverloadFactorBending")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def overload_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OverloadFactorContact")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def pitch_line_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PitchLineVelocity")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def pitting_resistance_geometry_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PittingResistanceGeometryFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def reliability_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReliabilityFactorBending")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def reliability_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReliabilityFactorContact")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def size_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SizeFactorBending")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def temperature_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TemperatureFactorBending")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def temperature_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TemperatureFactorContact")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def transmitted_tangential_load_at_large_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TransmittedTangentialLoadAtLargeEnd"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def transverse_contact_ratio(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TransverseContactRatio")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_SpiralBevelMeshSingleFlankRating":
        """Cast to another type.

        Returns:
            _Cast_SpiralBevelMeshSingleFlankRating
        """
        return _Cast_SpiralBevelMeshSingleFlankRating(self)



"""LobattoIIICTransientSolver"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.nodal_analysis.system_solvers import _126

_LOBATTO_IIIC_TRANSIENT_SOLVER = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.SystemSolvers", "LobattoIIICTransientSolver"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.nodal_analysis.system_solvers import (
        _115,
        _116,
        _125,
        _127,
        _129,
    )

    Self = TypeVar("Self", bound="LobattoIIICTransientSolver")
    CastSelf = TypeVar(
        "CastSelf", bound="LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver"
    )


__docformat__ = "restructuredtext en"
__all__ = ("LobattoIIICTransientSolver",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LobattoIIICTransientSolver:
    """Special nested class for casting LobattoIIICTransientSolver to subclasses."""

    __parent__: "LobattoIIICTransientSolver"

    @property
    def step_halving_transient_solver(
        self: "CastSelf",
    ) -> "_126.StepHalvingTransientSolver":
        return self.__parent__._cast(_126.StepHalvingTransientSolver)

    @property
    def internal_transient_solver(self: "CastSelf") -> "_116.InternalTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _116

        return self.__parent__._cast(_116.InternalTransientSolver)

    @property
    def transient_solver(self: "CastSelf") -> "_129.TransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _129

        return self.__parent__._cast(_129.TransientSolver)

    @property
    def dynamic_solver(self: "CastSelf") -> "_115.DynamicSolver":
        from mastapy._private.nodal_analysis.system_solvers import _115

        return self.__parent__._cast(_115.DynamicSolver)

    @property
    def stiffness_solver(self: "CastSelf") -> "_127.StiffnessSolver":
        from mastapy._private.nodal_analysis.system_solvers import _127

        return self.__parent__._cast(_127.StiffnessSolver)

    @property
    def solver(self: "CastSelf") -> "_125.Solver":
        from mastapy._private.nodal_analysis.system_solvers import _125

        return self.__parent__._cast(_125.Solver)

    @property
    def lobatto_iiic_transient_solver(self: "CastSelf") -> "LobattoIIICTransientSolver":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class LobattoIIICTransientSolver(_126.StepHalvingTransientSolver):
    """LobattoIIICTransientSolver

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LOBATTO_IIIC_TRANSIENT_SOLVER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_LobattoIIICTransientSolver":
        """Cast to another type.

        Returns:
            _Cast_LobattoIIICTransientSolver
        """
        return _Cast_LobattoIIICTransientSolver(self)



"""RotationAxis"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_ROTATION_AXIS = python_net_import("SMT.MastaAPI.MathUtility", "RotationAxis")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="RotationAxis")
    CastSelf = TypeVar("CastSelf", bound="RotationAxis._Cast_RotationAxis")


__docformat__ = "restructuredtext en"
__all__ = ("RotationAxis",)


class RotationAxis(Enum):
    """RotationAxis

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _ROTATION_AXIS

    X_AXIS = 0
    Y_AXIS = 1
    Z_AXIS = 2
    USERSPECIFIED = 3


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


RotationAxis.__setattr__ = __enum_setattr
RotationAxis.__delattr__ = __enum_delattr



"""ComponentPerModeResult"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import utility

_COMPONENT_PER_MODE_RESULT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Reporting",
    "ComponentPerModeResult",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results.modal_analyses.reporting import (
        _5051,
    )

    Self = TypeVar("Self", bound="ComponentPerModeResult")
    CastSelf = TypeVar(
        "CastSelf", bound="ComponentPerModeResult._Cast_ComponentPerModeResult"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ComponentPerModeResult",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ComponentPerModeResult:
    """Special nested class for casting ComponentPerModeResult to subclasses."""

    __parent__: "ComponentPerModeResult"

    @property
    def shaft_per_mode_result(self: "CastSelf") -> "_5051.ShaftPerModeResult":
        from mastapy._private.system_model.analyses_and_results.modal_analyses.reporting import (
            _5051,
        )

        return self.__parent__._cast(_5051.ShaftPerModeResult)

    @property
    def component_per_mode_result(self: "CastSelf") -> "ComponentPerModeResult":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ComponentPerModeResult(_0.APIBase):
    """ComponentPerModeResult

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _COMPONENT_PER_MODE_RESULT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def mode_frequency(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ModeFrequency")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def mode_id(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ModeID")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def percentage_kinetic_energy(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PercentageKineticEnergy")

        if temp is None:
            return 0.0

        return temp

    @percentage_kinetic_energy.setter
    @exception_bridge
    @enforce_parameter_types
    def percentage_kinetic_energy(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PercentageKineticEnergy",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def percentage_strain_energy(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PercentageStrainEnergy")

        if temp is None:
            return 0.0

        return temp

    @percentage_strain_energy.setter
    @exception_bridge
    @enforce_parameter_types
    def percentage_strain_energy(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PercentageStrainEnergy",
            float(value) if value is not None else 0.0,
        )

    @property
    def cast_to(self: "Self") -> "_Cast_ComponentPerModeResult":
        """Cast to another type.

        Returns:
            _Cast_ComponentPerModeResult
        """
        return _Cast_ComponentPerModeResult(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.gear_set_pareto_optimiser._1027 import BarForPareto
    from mastapy._private.gears.gear_set_pareto_optimiser._1028 import (
        CandidateDisplayChoice,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1029 import ChartInfoBase
    from mastapy._private.gears.gear_set_pareto_optimiser._1030 import (
        CylindricalGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1031 import (
        DesignSpaceSearchBase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1032 import (
        DesignSpaceSearchCandidateBase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1033 import (
        FaceGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1034 import GearNameMapper
    from mastapy._private.gears.gear_set_pareto_optimiser._1035 import GearNamePicker
    from mastapy._private.gears.gear_set_pareto_optimiser._1036 import (
        GearSetOptimiserCandidate,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1037 import (
        GearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1038 import (
        HypoidGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1039 import (
        InputSliderForPareto,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1040 import LargerOrSmaller
    from mastapy._private.gears.gear_set_pareto_optimiser._1041 import (
        MicroGeometryDesignSpaceSearch,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1042 import (
        MicroGeometryDesignSpaceSearchCandidate,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1043 import (
        MicroGeometryDesignSpaceSearchChartInformation,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1044 import (
        MicroGeometryDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1045 import (
        MicroGeometryGearSetDesignSpaceSearch,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1046 import (
        MicroGeometryGearSetDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1047 import (
        MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1048 import (
        OptimisationTarget,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1049 import (
        ParetoConicalRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1050 import (
        ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1051 import (
        ParetoCylindricalGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1052 import (
        ParetoCylindricalRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1053 import (
        ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1054 import (
        ParetoFaceGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1055 import (
        ParetoFaceRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1056 import (
        ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1057 import (
        ParetoHypoidGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1058 import (
        ParetoOptimiserChartInformation,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1059 import (
        ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1060 import (
        ParetoSpiralBevelGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1061 import (
        ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1062 import (
        ParetoStraightBevelGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1063 import (
        ReasonsForInvalidDesigns,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1064 import (
        SpiralBevelGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1065 import (
        StraightBevelGearSetParetoOptimiser,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_set_pareto_optimiser._1027": ["BarForPareto"],
        "_private.gears.gear_set_pareto_optimiser._1028": ["CandidateDisplayChoice"],
        "_private.gears.gear_set_pareto_optimiser._1029": ["ChartInfoBase"],
        "_private.gears.gear_set_pareto_optimiser._1030": [
            "CylindricalGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._1031": ["DesignSpaceSearchBase"],
        "_private.gears.gear_set_pareto_optimiser._1032": [
            "DesignSpaceSearchCandidateBase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1033": [
            "FaceGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._1034": ["GearNameMapper"],
        "_private.gears.gear_set_pareto_optimiser._1035": ["GearNamePicker"],
        "_private.gears.gear_set_pareto_optimiser._1036": ["GearSetOptimiserCandidate"],
        "_private.gears.gear_set_pareto_optimiser._1037": ["GearSetParetoOptimiser"],
        "_private.gears.gear_set_pareto_optimiser._1038": [
            "HypoidGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._1039": ["InputSliderForPareto"],
        "_private.gears.gear_set_pareto_optimiser._1040": ["LargerOrSmaller"],
        "_private.gears.gear_set_pareto_optimiser._1041": [
            "MicroGeometryDesignSpaceSearch"
        ],
        "_private.gears.gear_set_pareto_optimiser._1042": [
            "MicroGeometryDesignSpaceSearchCandidate"
        ],
        "_private.gears.gear_set_pareto_optimiser._1043": [
            "MicroGeometryDesignSpaceSearchChartInformation"
        ],
        "_private.gears.gear_set_pareto_optimiser._1044": [
            "MicroGeometryDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1045": [
            "MicroGeometryGearSetDesignSpaceSearch"
        ],
        "_private.gears.gear_set_pareto_optimiser._1046": [
            "MicroGeometryGearSetDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1047": [
            "MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1048": ["OptimisationTarget"],
        "_private.gears.gear_set_pareto_optimiser._1049": [
            "ParetoConicalRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1050": [
            "ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1051": [
            "ParetoCylindricalGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1052": [
            "ParetoCylindricalRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1053": [
            "ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1054": [
            "ParetoFaceGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1055": [
            "ParetoFaceRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1056": [
            "ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1057": [
            "ParetoHypoidGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1058": [
            "ParetoOptimiserChartInformation"
        ],
        "_private.gears.gear_set_pareto_optimiser._1059": [
            "ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1060": [
            "ParetoSpiralBevelGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1061": [
            "ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1062": [
            "ParetoStraightBevelGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1063": ["ReasonsForInvalidDesigns"],
        "_private.gears.gear_set_pareto_optimiser._1064": [
            "SpiralBevelGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._1065": [
            "StraightBevelGearSetParetoOptimiser"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BarForPareto",
    "CandidateDisplayChoice",
    "ChartInfoBase",
    "CylindricalGearSetParetoOptimiser",
    "DesignSpaceSearchBase",
    "DesignSpaceSearchCandidateBase",
    "FaceGearSetParetoOptimiser",
    "GearNameMapper",
    "GearNamePicker",
    "GearSetOptimiserCandidate",
    "GearSetParetoOptimiser",
    "HypoidGearSetParetoOptimiser",
    "InputSliderForPareto",
    "LargerOrSmaller",
    "MicroGeometryDesignSpaceSearch",
    "MicroGeometryDesignSpaceSearchCandidate",
    "MicroGeometryDesignSpaceSearchChartInformation",
    "MicroGeometryDesignSpaceSearchStrategyDatabase",
    "MicroGeometryGearSetDesignSpaceSearch",
    "MicroGeometryGearSetDesignSpaceSearchStrategyDatabase",
    "MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase",
    "OptimisationTarget",
    "ParetoConicalRatingOptimisationStrategyDatabase",
    "ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoCylindricalGearSetOptimisationStrategyDatabase",
    "ParetoCylindricalRatingOptimisationStrategyDatabase",
    "ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoFaceGearSetOptimisationStrategyDatabase",
    "ParetoFaceRatingOptimisationStrategyDatabase",
    "ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoHypoidGearSetOptimisationStrategyDatabase",
    "ParetoOptimiserChartInformation",
    "ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoSpiralBevelGearSetOptimisationStrategyDatabase",
    "ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoStraightBevelGearSetOptimisationStrategyDatabase",
    "ReasonsForInvalidDesigns",
    "SpiralBevelGearSetParetoOptimiser",
    "StraightBevelGearSetParetoOptimiser",
)



"""VirtualComponentMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)
from mastapy._private._math.vector_3d import Vector3D

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5803

_VIRTUAL_COMPONENT_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses",
    "VirtualComponentMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7947,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
        _5741,
        _5796,
        _5800,
        _5806,
        _5813,
        _5814,
        _5854,
    )
    from mastapy._private.system_model.part_model import _2756

    Self = TypeVar("Self", bound="VirtualComponentMultibodyDynamicsAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="VirtualComponentMultibodyDynamicsAnalysis._Cast_VirtualComponentMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("VirtualComponentMultibodyDynamicsAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_VirtualComponentMultibodyDynamicsAnalysis:
    """Special nested class for casting VirtualComponentMultibodyDynamicsAnalysis to subclasses."""

    __parent__: "VirtualComponentMultibodyDynamicsAnalysis"

    @property
    def mountable_component_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5803.MountableComponentMultibodyDynamicsAnalysis":
        return self.__parent__._cast(_5803.MountableComponentMultibodyDynamicsAnalysis)

    @property
    def component_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5741.ComponentMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5741,
        )

        return self.__parent__._cast(_5741.ComponentMultibodyDynamicsAnalysis)

    @property
    def part_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5806.PartMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5806,
        )

        return self.__parent__._cast(_5806.PartMultibodyDynamicsAnalysis)

    @property
    def part_time_series_load_analysis_case(
        self: "CastSelf",
    ) -> "_7947.PartTimeSeriesLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7947,
        )

        return self.__parent__._cast(_7947.PartTimeSeriesLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def mass_disc_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5796.MassDiscMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5796,
        )

        return self.__parent__._cast(_5796.MassDiscMultibodyDynamicsAnalysis)

    @property
    def measurement_component_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5800.MeasurementComponentMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5800,
        )

        return self.__parent__._cast(
            _5800.MeasurementComponentMultibodyDynamicsAnalysis
        )

    @property
    def point_load_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5813.PointLoadMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5813,
        )

        return self.__parent__._cast(_5813.PointLoadMultibodyDynamicsAnalysis)

    @property
    def power_load_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5814.PowerLoadMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5814,
        )

        return self.__parent__._cast(_5814.PowerLoadMultibodyDynamicsAnalysis)

    @property
    def unbalanced_mass_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5854.UnbalancedMassMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5854,
        )

        return self.__parent__._cast(_5854.UnbalancedMassMultibodyDynamicsAnalysis)

    @property
    def virtual_component_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "VirtualComponentMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class VirtualComponentMultibodyDynamicsAnalysis(
    _5803.MountableComponentMultibodyDynamicsAnalysis
):
    """VirtualComponentMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _VIRTUAL_COMPONENT_MULTIBODY_DYNAMICS_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def acceleration_translation_local_coordinate_system(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "AccelerationTranslationLocalCoordinateSystem"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def displacement_translation_local_coordinate_system(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DisplacementTranslationLocalCoordinateSystem"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def velocity_translation_local_coordinate_system(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "VelocityTranslationLocalCoordinateSystem"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2756.VirtualComponent":
        """mastapy.system_model.part_model.VirtualComponent

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_VirtualComponentMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_VirtualComponentMultibodyDynamicsAnalysis
        """
        return _Cast_VirtualComponentMultibodyDynamicsAnalysis(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6776 import (
        AbstractAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6777 import (
        AbstractShaftCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6778 import (
        AbstractShaftOrHousingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6779 import (
        AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6780 import (
        AGMAGleasonConicalGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6781 import (
        AGMAGleasonConicalGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6782 import (
        AGMAGleasonConicalGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6783 import (
        AssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6784 import (
        BearingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6785 import (
        BeltConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6786 import (
        BeltDriveCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6787 import (
        BevelDifferentialGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6788 import (
        BevelDifferentialGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6789 import (
        BevelDifferentialGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6790 import (
        BevelDifferentialPlanetGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6791 import (
        BevelDifferentialSunGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6792 import (
        BevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6793 import (
        BevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6794 import (
        BevelGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6795 import (
        BoltCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6796 import (
        BoltedJointCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6797 import (
        ClutchCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6798 import (
        ClutchConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6799 import (
        ClutchHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6800 import (
        CoaxialConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6801 import (
        ComponentCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6802 import (
        ConceptCouplingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6803 import (
        ConceptCouplingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6804 import (
        ConceptCouplingHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6805 import (
        ConceptGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6806 import (
        ConceptGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6807 import (
        ConceptGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6808 import (
        ConicalGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6809 import (
        ConicalGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6810 import (
        ConicalGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6811 import (
        ConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6812 import (
        ConnectorCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6813 import (
        CouplingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6814 import (
        CouplingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6815 import (
        CouplingHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6816 import (
        CVTBeltConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6817 import (
        CVTCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6818 import (
        CVTPulleyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6819 import (
        CycloidalAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6820 import (
        CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6821 import (
        CycloidalDiscCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6822 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6823 import (
        CylindricalGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6824 import (
        CylindricalGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6825 import (
        CylindricalGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6826 import (
        CylindricalPlanetGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6827 import (
        DatumCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6828 import (
        ExternalCADModelCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6829 import (
        FaceGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6830 import (
        FaceGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6831 import (
        FaceGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6832 import (
        FEPartCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6833 import (
        FlexiblePinAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6834 import (
        GearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6835 import (
        GearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6836 import (
        GearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6837 import (
        GuideDxfModelCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6838 import (
        HypoidGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6839 import (
        HypoidGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6840 import (
        HypoidGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6841 import (
        InterMountableComponentConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6842 import (
        KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6843 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6844 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6845 import (
        KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6846 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6847 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6848 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6849 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6850 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6851 import (
        MassDiscCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6852 import (
        MeasurementComponentCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6853 import (
        MicrophoneArrayCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6854 import (
        MicrophoneCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6855 import (
        MountableComponentCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6856 import (
        OilSealCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6857 import (
        PartCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6858 import (
        PartToPartShearCouplingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6859 import (
        PartToPartShearCouplingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6860 import (
        PartToPartShearCouplingHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6861 import (
        PlanetaryConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6862 import (
        PlanetaryGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6863 import (
        PlanetCarrierCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6864 import (
        PointLoadCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6865 import (
        PowerLoadCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6866 import (
        PulleyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6867 import (
        RingPinsCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6868 import (
        RingPinsToDiscConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6869 import (
        RollingRingAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6870 import (
        RollingRingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6871 import (
        RollingRingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6872 import (
        RootAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6873 import (
        ShaftCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6874 import (
        ShaftHubConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6875 import (
        ShaftToMountableComponentConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6876 import (
        SpecialisedAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6877 import (
        SpiralBevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6878 import (
        SpiralBevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6879 import (
        SpiralBevelGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6880 import (
        SpringDamperCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6881 import (
        SpringDamperConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6882 import (
        SpringDamperHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6883 import (
        StraightBevelDiffGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6884 import (
        StraightBevelDiffGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6885 import (
        StraightBevelDiffGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6886 import (
        StraightBevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6887 import (
        StraightBevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6888 import (
        StraightBevelGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6889 import (
        StraightBevelPlanetGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6890 import (
        StraightBevelSunGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6891 import (
        SynchroniserCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6892 import (
        SynchroniserHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6893 import (
        SynchroniserPartCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6894 import (
        SynchroniserSleeveCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6895 import (
        TorqueConverterCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6896 import (
        TorqueConverterConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6897 import (
        TorqueConverterPumpCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6898 import (
        TorqueConverterTurbineCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6899 import (
        UnbalancedMassCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6900 import (
        VirtualComponentCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6901 import (
        WormGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6902 import (
        WormGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6903 import (
        WormGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6904 import (
        ZerolBevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6905 import (
        ZerolBevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6906 import (
        ZerolBevelGearSetCompoundDynamicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6776": [
            "AbstractAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6777": [
            "AbstractShaftCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6778": [
            "AbstractShaftOrHousingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6779": [
            "AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6780": [
            "AGMAGleasonConicalGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6781": [
            "AGMAGleasonConicalGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6782": [
            "AGMAGleasonConicalGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6783": [
            "AssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6784": [
            "BearingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6785": [
            "BeltConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6786": [
            "BeltDriveCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6787": [
            "BevelDifferentialGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6788": [
            "BevelDifferentialGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6789": [
            "BevelDifferentialGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6790": [
            "BevelDifferentialPlanetGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6791": [
            "BevelDifferentialSunGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6792": [
            "BevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6793": [
            "BevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6794": [
            "BevelGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6795": [
            "BoltCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6796": [
            "BoltedJointCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6797": [
            "ClutchCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6798": [
            "ClutchConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6799": [
            "ClutchHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6800": [
            "CoaxialConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6801": [
            "ComponentCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6802": [
            "ConceptCouplingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6803": [
            "ConceptCouplingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6804": [
            "ConceptCouplingHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6805": [
            "ConceptGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6806": [
            "ConceptGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6807": [
            "ConceptGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6808": [
            "ConicalGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6809": [
            "ConicalGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6810": [
            "ConicalGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6811": [
            "ConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6812": [
            "ConnectorCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6813": [
            "CouplingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6814": [
            "CouplingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6815": [
            "CouplingHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6816": [
            "CVTBeltConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6817": [
            "CVTCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6818": [
            "CVTPulleyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6819": [
            "CycloidalAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6820": [
            "CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6821": [
            "CycloidalDiscCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6822": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6823": [
            "CylindricalGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6824": [
            "CylindricalGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6825": [
            "CylindricalGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6826": [
            "CylindricalPlanetGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6827": [
            "DatumCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6828": [
            "ExternalCADModelCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6829": [
            "FaceGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6830": [
            "FaceGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6831": [
            "FaceGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6832": [
            "FEPartCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6833": [
            "FlexiblePinAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6834": [
            "GearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6835": [
            "GearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6836": [
            "GearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6837": [
            "GuideDxfModelCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6838": [
            "HypoidGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6839": [
            "HypoidGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6840": [
            "HypoidGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6841": [
            "InterMountableComponentConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6842": [
            "KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6843": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6844": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6845": [
            "KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6846": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6847": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6848": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6849": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6850": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6851": [
            "MassDiscCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6852": [
            "MeasurementComponentCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6853": [
            "MicrophoneArrayCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6854": [
            "MicrophoneCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6855": [
            "MountableComponentCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6856": [
            "OilSealCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6857": [
            "PartCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6858": [
            "PartToPartShearCouplingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6859": [
            "PartToPartShearCouplingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6860": [
            "PartToPartShearCouplingHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6861": [
            "PlanetaryConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6862": [
            "PlanetaryGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6863": [
            "PlanetCarrierCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6864": [
            "PointLoadCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6865": [
            "PowerLoadCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6866": [
            "PulleyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6867": [
            "RingPinsCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6868": [
            "RingPinsToDiscConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6869": [
            "RollingRingAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6870": [
            "RollingRingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6871": [
            "RollingRingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6872": [
            "RootAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6873": [
            "ShaftCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6874": [
            "ShaftHubConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6875": [
            "ShaftToMountableComponentConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6876": [
            "SpecialisedAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6877": [
            "SpiralBevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6878": [
            "SpiralBevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6879": [
            "SpiralBevelGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6880": [
            "SpringDamperCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6881": [
            "SpringDamperConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6882": [
            "SpringDamperHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6883": [
            "StraightBevelDiffGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6884": [
            "StraightBevelDiffGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6885": [
            "StraightBevelDiffGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6886": [
            "StraightBevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6887": [
            "StraightBevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6888": [
            "StraightBevelGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6889": [
            "StraightBevelPlanetGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6890": [
            "StraightBevelSunGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6891": [
            "SynchroniserCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6892": [
            "SynchroniserHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6893": [
            "SynchroniserPartCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6894": [
            "SynchroniserSleeveCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6895": [
            "TorqueConverterCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6896": [
            "TorqueConverterConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6897": [
            "TorqueConverterPumpCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6898": [
            "TorqueConverterTurbineCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6899": [
            "UnbalancedMassCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6900": [
            "VirtualComponentCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6901": [
            "WormGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6902": [
            "WormGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6903": [
            "WormGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6904": [
            "ZerolBevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6905": [
            "ZerolBevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6906": [
            "ZerolBevelGearSetCompoundDynamicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundDynamicAnalysis",
    "AbstractShaftCompoundDynamicAnalysis",
    "AbstractShaftOrHousingCompoundDynamicAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearMeshCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearSetCompoundDynamicAnalysis",
    "AssemblyCompoundDynamicAnalysis",
    "BearingCompoundDynamicAnalysis",
    "BeltConnectionCompoundDynamicAnalysis",
    "BeltDriveCompoundDynamicAnalysis",
    "BevelDifferentialGearCompoundDynamicAnalysis",
    "BevelDifferentialGearMeshCompoundDynamicAnalysis",
    "BevelDifferentialGearSetCompoundDynamicAnalysis",
    "BevelDifferentialPlanetGearCompoundDynamicAnalysis",
    "BevelDifferentialSunGearCompoundDynamicAnalysis",
    "BevelGearCompoundDynamicAnalysis",
    "BevelGearMeshCompoundDynamicAnalysis",
    "BevelGearSetCompoundDynamicAnalysis",
    "BoltCompoundDynamicAnalysis",
    "BoltedJointCompoundDynamicAnalysis",
    "ClutchCompoundDynamicAnalysis",
    "ClutchConnectionCompoundDynamicAnalysis",
    "ClutchHalfCompoundDynamicAnalysis",
    "CoaxialConnectionCompoundDynamicAnalysis",
    "ComponentCompoundDynamicAnalysis",
    "ConceptCouplingCompoundDynamicAnalysis",
    "ConceptCouplingConnectionCompoundDynamicAnalysis",
    "ConceptCouplingHalfCompoundDynamicAnalysis",
    "ConceptGearCompoundDynamicAnalysis",
    "ConceptGearMeshCompoundDynamicAnalysis",
    "ConceptGearSetCompoundDynamicAnalysis",
    "ConicalGearCompoundDynamicAnalysis",
    "ConicalGearMeshCompoundDynamicAnalysis",
    "ConicalGearSetCompoundDynamicAnalysis",
    "ConnectionCompoundDynamicAnalysis",
    "ConnectorCompoundDynamicAnalysis",
    "CouplingCompoundDynamicAnalysis",
    "CouplingConnectionCompoundDynamicAnalysis",
    "CouplingHalfCompoundDynamicAnalysis",
    "CVTBeltConnectionCompoundDynamicAnalysis",
    "CVTCompoundDynamicAnalysis",
    "CVTPulleyCompoundDynamicAnalysis",
    "CycloidalAssemblyCompoundDynamicAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis",
    "CycloidalDiscCompoundDynamicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis",
    "CylindricalGearCompoundDynamicAnalysis",
    "CylindricalGearMeshCompoundDynamicAnalysis",
    "CylindricalGearSetCompoundDynamicAnalysis",
    "CylindricalPlanetGearCompoundDynamicAnalysis",
    "DatumCompoundDynamicAnalysis",
    "ExternalCADModelCompoundDynamicAnalysis",
    "FaceGearCompoundDynamicAnalysis",
    "FaceGearMeshCompoundDynamicAnalysis",
    "FaceGearSetCompoundDynamicAnalysis",
    "FEPartCompoundDynamicAnalysis",
    "FlexiblePinAssemblyCompoundDynamicAnalysis",
    "GearCompoundDynamicAnalysis",
    "GearMeshCompoundDynamicAnalysis",
    "GearSetCompoundDynamicAnalysis",
    "GuideDxfModelCompoundDynamicAnalysis",
    "HypoidGearCompoundDynamicAnalysis",
    "HypoidGearMeshCompoundDynamicAnalysis",
    "HypoidGearSetCompoundDynamicAnalysis",
    "InterMountableComponentConnectionCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis",
    "MassDiscCompoundDynamicAnalysis",
    "MeasurementComponentCompoundDynamicAnalysis",
    "MicrophoneArrayCompoundDynamicAnalysis",
    "MicrophoneCompoundDynamicAnalysis",
    "MountableComponentCompoundDynamicAnalysis",
    "OilSealCompoundDynamicAnalysis",
    "PartCompoundDynamicAnalysis",
    "PartToPartShearCouplingCompoundDynamicAnalysis",
    "PartToPartShearCouplingConnectionCompoundDynamicAnalysis",
    "PartToPartShearCouplingHalfCompoundDynamicAnalysis",
    "PlanetaryConnectionCompoundDynamicAnalysis",
    "PlanetaryGearSetCompoundDynamicAnalysis",
    "PlanetCarrierCompoundDynamicAnalysis",
    "PointLoadCompoundDynamicAnalysis",
    "PowerLoadCompoundDynamicAnalysis",
    "PulleyCompoundDynamicAnalysis",
    "RingPinsCompoundDynamicAnalysis",
    "RingPinsToDiscConnectionCompoundDynamicAnalysis",
    "RollingRingAssemblyCompoundDynamicAnalysis",
    "RollingRingCompoundDynamicAnalysis",
    "RollingRingConnectionCompoundDynamicAnalysis",
    "RootAssemblyCompoundDynamicAnalysis",
    "ShaftCompoundDynamicAnalysis",
    "ShaftHubConnectionCompoundDynamicAnalysis",
    "ShaftToMountableComponentConnectionCompoundDynamicAnalysis",
    "SpecialisedAssemblyCompoundDynamicAnalysis",
    "SpiralBevelGearCompoundDynamicAnalysis",
    "SpiralBevelGearMeshCompoundDynamicAnalysis",
    "SpiralBevelGearSetCompoundDynamicAnalysis",
    "SpringDamperCompoundDynamicAnalysis",
    "SpringDamperConnectionCompoundDynamicAnalysis",
    "SpringDamperHalfCompoundDynamicAnalysis",
    "StraightBevelDiffGearCompoundDynamicAnalysis",
    "StraightBevelDiffGearMeshCompoundDynamicAnalysis",
    "StraightBevelDiffGearSetCompoundDynamicAnalysis",
    "StraightBevelGearCompoundDynamicAnalysis",
    "StraightBevelGearMeshCompoundDynamicAnalysis",
    "StraightBevelGearSetCompoundDynamicAnalysis",
    "StraightBevelPlanetGearCompoundDynamicAnalysis",
    "StraightBevelSunGearCompoundDynamicAnalysis",
    "SynchroniserCompoundDynamicAnalysis",
    "SynchroniserHalfCompoundDynamicAnalysis",
    "SynchroniserPartCompoundDynamicAnalysis",
    "SynchroniserSleeveCompoundDynamicAnalysis",
    "TorqueConverterCompoundDynamicAnalysis",
    "TorqueConverterConnectionCompoundDynamicAnalysis",
    "TorqueConverterPumpCompoundDynamicAnalysis",
    "TorqueConverterTurbineCompoundDynamicAnalysis",
    "UnbalancedMassCompoundDynamicAnalysis",
    "VirtualComponentCompoundDynamicAnalysis",
    "WormGearCompoundDynamicAnalysis",
    "WormGearMeshCompoundDynamicAnalysis",
    "WormGearSetCompoundDynamicAnalysis",
    "ZerolBevelGearCompoundDynamicAnalysis",
    "ZerolBevelGearMeshCompoundDynamicAnalysis",
    "ZerolBevelGearSetCompoundDynamicAnalysis",
)



"""RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import utility
from mastapy._private.system_model.analyses_and_results.modal_analyses.reporting import (
    _5049,
)

_RIGIDLY_CONNECTED_DESIGN_ENTITY_GROUP_FOR_SINGLE_EXCITATION_MODAL_ANALYSIS = (
    python_net_import(
        "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Reporting",
        "RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis",
    )
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar(
        "Self",
        bound="RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis",
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis._Cast_RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis:
    """Special nested class for casting RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis to subclasses."""

    __parent__: "RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis"

    @property
    def rigidly_connected_design_entity_group_for_single_mode_modal_analysis(
        self: "CastSelf",
    ) -> "_5049.RigidlyConnectedDesignEntityGroupForSingleModeModalAnalysis":
        return self.__parent__._cast(
            _5049.RigidlyConnectedDesignEntityGroupForSingleModeModalAnalysis
        )

    @property
    def rigidly_connected_design_entity_group_for_single_excitation_modal_analysis(
        self: "CastSelf",
    ) -> "RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis(
    _5049.RigidlyConnectedDesignEntityGroupForSingleModeModalAnalysis
):
    """RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _RIGIDLY_CONNECTED_DESIGN_ENTITY_GROUP_FOR_SINGLE_EXCITATION_MODAL_ANALYSIS
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def reference_speed_of_crossing(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReferenceSpeedOfCrossing")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis":
        """Cast to another type.

        Returns:
            _Cast_RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis
        """
        return _Cast_RigidlyConnectedDesignEntityGroupForSingleExcitationModalAnalysis(
            self
        )



"""GearNURBSSurface"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.gears import _426

_GEAR_NURBS_SURFACE = python_net_import("SMT.MastaAPI.Gears", "GearNURBSSurface")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="GearNURBSSurface")
    CastSelf = TypeVar("CastSelf", bound="GearNURBSSurface._Cast_GearNURBSSurface")


__docformat__ = "restructuredtext en"
__all__ = ("GearNURBSSurface",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearNURBSSurface:
    """Special nested class for casting GearNURBSSurface to subclasses."""

    __parent__: "GearNURBSSurface"

    @property
    def conical_gear_tooth_surface(self: "CastSelf") -> "_426.ConicalGearToothSurface":
        return self.__parent__._cast(_426.ConicalGearToothSurface)

    @property
    def gear_nurbs_surface(self: "CastSelf") -> "GearNURBSSurface":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class GearNURBSSurface(_426.ConicalGearToothSurface):
    """GearNURBSSurface

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_NURBS_SURFACE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_GearNURBSSurface":
        """Cast to another type.

        Returns:
            _Cast_GearNURBSSurface
        """
        return _Cast_GearNURBSSurface(self)



"""TorqueConverterConnectionMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5753

_TORQUE_CONVERTER_CONNECTION_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses",
    "TorqueConverterConnectionMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7936,
        _7940,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
        _5751,
        _5786,
        _5852,
    )
    from mastapy._private.system_model.analyses_and_results.static_loads import _7900
    from mastapy._private.system_model.connections_and_sockets.couplings import _2612

    Self = TypeVar("Self", bound="TorqueConverterConnectionMultibodyDynamicsAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("TorqueConverterConnectionMultibodyDynamicsAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis:
    """Special nested class for casting TorqueConverterConnectionMultibodyDynamicsAnalysis to subclasses."""

    __parent__: "TorqueConverterConnectionMultibodyDynamicsAnalysis"

    @property
    def coupling_connection_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5753.CouplingConnectionMultibodyDynamicsAnalysis":
        return self.__parent__._cast(_5753.CouplingConnectionMultibodyDynamicsAnalysis)

    @property
    def inter_mountable_component_connection_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5786.InterMountableComponentConnectionMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5786,
        )

        return self.__parent__._cast(
            _5786.InterMountableComponentConnectionMultibodyDynamicsAnalysis
        )

    @property
    def connection_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5751.ConnectionMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5751,
        )

        return self.__parent__._cast(_5751.ConnectionMultibodyDynamicsAnalysis)

    @property
    def connection_time_series_load_analysis_case(
        self: "CastSelf",
    ) -> "_7940.ConnectionTimeSeriesLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7940,
        )

        return self.__parent__._cast(_7940.ConnectionTimeSeriesLoadAnalysisCase)

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7936.ConnectionAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7936,
        )

        return self.__parent__._cast(_7936.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def torque_converter_connection_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "TorqueConverterConnectionMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class TorqueConverterConnectionMultibodyDynamicsAnalysis(
    _5753.CouplingConnectionMultibodyDynamicsAnalysis
):
    """TorqueConverterConnectionMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TORQUE_CONVERTER_CONNECTION_MULTIBODY_DYNAMICS_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def capacity_factor_k(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CapacityFactorK")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def inverse_capacity_factor_1k(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InverseCapacityFactor1K")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def is_locked(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsLocked")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def lock_up_clutch_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LockUpClutchTemperature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def lock_up_viscous_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LockUpViscousTorque")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def locked_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LockedTorque")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def locking_status(self: "Self") -> "_5852.TorqueConverterStatus":
        """mastapy.system_model.analyses_and_results.mbd_analyses.TorqueConverterStatus

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LockingStatus")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.TorqueConverterStatus",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.system_model.analyses_and_results.mbd_analyses._5852",
            "TorqueConverterStatus",
        )(value)

    @property
    @exception_bridge
    def percentage_applied_pressure(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PercentageAppliedPressure")

        if temp is None:
            return 0.0

        return temp

    @percentage_applied_pressure.setter
    @exception_bridge
    @enforce_parameter_types
    def percentage_applied_pressure(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PercentageAppliedPressure",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def power_loss(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PowerLoss")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def pump_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PumpTorque")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def speed_ratio(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SpeedRatio")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def torque_ratio(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TorqueRatio")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def turbine_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TurbineTorque")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2612.TorqueConverterConnection":
        """mastapy.system_model.connections_and_sockets.couplings.TorqueConverterConnection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_load_case(self: "Self") -> "_7900.TorqueConverterConnectionLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.TorqueConverterConnectionLoadCase

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionLoadCase")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis
        """
        return _Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis(self)



"""ShaftRatingMethod"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_SHAFT_RATING_METHOD = python_net_import("SMT.MastaAPI.Shafts", "ShaftRatingMethod")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ShaftRatingMethod")
    CastSelf = TypeVar("CastSelf", bound="ShaftRatingMethod._Cast_ShaftRatingMethod")


__docformat__ = "restructuredtext en"
__all__ = ("ShaftRatingMethod",)


class ShaftRatingMethod(Enum):
    """ShaftRatingMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _SHAFT_RATING_METHOD

    DIN_743201212 = 0
    SMT = 1
    AGMA_60016101E08 = 2
    FKM_GUIDELINE_6TH_EDITION_2012 = 3


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ShaftRatingMethod.__setattr__ = __enum_setattr
ShaftRatingMethod.__delattr__ = __enum_delattr



"""ConicalGearMeshCompoundParametricStudyTool"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
    _4823,
)

_CONICAL_GEAR_MESH_COMPOUND_PARAMETRIC_STUDY_TOOL = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools.Compound",
    "ConicalGearMeshCompoundParametricStudyTool",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7937,
        _7941,
    )
    from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
        _4646,
    )
    from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
        _4769,
        _4776,
        _4781,
        _4799,
        _4827,
        _4829,
        _4831,
        _4834,
        _4837,
        _4866,
        _4872,
        _4875,
        _4893,
    )

    Self = TypeVar("Self", bound="ConicalGearMeshCompoundParametricStudyTool")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConicalGearMeshCompoundParametricStudyTool._Cast_ConicalGearMeshCompoundParametricStudyTool",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGearMeshCompoundParametricStudyTool",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalGearMeshCompoundParametricStudyTool:
    """Special nested class for casting ConicalGearMeshCompoundParametricStudyTool to subclasses."""

    __parent__: "ConicalGearMeshCompoundParametricStudyTool"

    @property
    def gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4823.GearMeshCompoundParametricStudyTool":
        return self.__parent__._cast(_4823.GearMeshCompoundParametricStudyTool)

    @property
    def inter_mountable_component_connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4829.InterMountableComponentConnectionCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4829,
        )

        return self.__parent__._cast(
            _4829.InterMountableComponentConnectionCompoundParametricStudyTool
        )

    @property
    def connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4799.ConnectionCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4799,
        )

        return self.__parent__._cast(_4799.ConnectionCompoundParametricStudyTool)

    @property
    def connection_compound_analysis(
        self: "CastSelf",
    ) -> "_7937.ConnectionCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7937,
        )

        return self.__parent__._cast(_7937.ConnectionCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4769.AGMAGleasonConicalGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4769,
        )

        return self.__parent__._cast(
            _4769.AGMAGleasonConicalGearMeshCompoundParametricStudyTool
        )

    @property
    def bevel_differential_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4776.BevelDifferentialGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4776,
        )

        return self.__parent__._cast(
            _4776.BevelDifferentialGearMeshCompoundParametricStudyTool
        )

    @property
    def bevel_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4781.BevelGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4781,
        )

        return self.__parent__._cast(_4781.BevelGearMeshCompoundParametricStudyTool)

    @property
    def hypoid_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4827.HypoidGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4827,
        )

        return self.__parent__._cast(_4827.HypoidGearMeshCompoundParametricStudyTool)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4831.KlingelnbergCycloPalloidConicalGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4831,
        )

        return self.__parent__._cast(
            _4831.KlingelnbergCycloPalloidConicalGearMeshCompoundParametricStudyTool
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4834.KlingelnbergCycloPalloidHypoidGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4834,
        )

        return self.__parent__._cast(
            _4834.KlingelnbergCycloPalloidHypoidGearMeshCompoundParametricStudyTool
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4837.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4837,
        )

        return self.__parent__._cast(
            _4837.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundParametricStudyTool
        )

    @property
    def spiral_bevel_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4866.SpiralBevelGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4866,
        )

        return self.__parent__._cast(
            _4866.SpiralBevelGearMeshCompoundParametricStudyTool
        )

    @property
    def straight_bevel_diff_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4872.StraightBevelDiffGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4872,
        )

        return self.__parent__._cast(
            _4872.StraightBevelDiffGearMeshCompoundParametricStudyTool
        )

    @property
    def straight_bevel_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4875.StraightBevelGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4875,
        )

        return self.__parent__._cast(
            _4875.StraightBevelGearMeshCompoundParametricStudyTool
        )

    @property
    def zerol_bevel_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4893.ZerolBevelGearMeshCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4893,
        )

        return self.__parent__._cast(
            _4893.ZerolBevelGearMeshCompoundParametricStudyTool
        )

    @property
    def conical_gear_mesh_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "ConicalGearMeshCompoundParametricStudyTool":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConicalGearMeshCompoundParametricStudyTool(
    _4823.GearMeshCompoundParametricStudyTool
):
    """ConicalGearMeshCompoundParametricStudyTool

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONICAL_GEAR_MESH_COMPOUND_PARAMETRIC_STUDY_TOOL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def planetaries(self: "Self") -> "List[ConicalGearMeshCompoundParametricStudyTool]":
        """List[mastapy.system_model.analyses_and_results.parametric_study_tools.compound.ConicalGearMeshCompoundParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Planetaries")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def connection_analysis_cases(
        self: "Self",
    ) -> "List[_4646.ConicalGearMeshParametricStudyTool]":
        """List[mastapy.system_model.analyses_and_results.parametric_study_tools.ConicalGearMeshParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def connection_analysis_cases_ready(
        self: "Self",
    ) -> "List[_4646.ConicalGearMeshParametricStudyTool]":
        """List[mastapy.system_model.analyses_and_results.parametric_study_tools.ConicalGearMeshParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ConicalGearMeshCompoundParametricStudyTool":
        """Cast to another type.

        Returns:
            _Cast_ConicalGearMeshCompoundParametricStudyTool
        """
        return _Cast_ConicalGearMeshCompoundParametricStudyTool(self)
